@@ -20,7 +20,7 @@ def pytest_assertrepr_compare(config, op, left, right):
 
         # Join lines side by side
         diff_view = [
-            f"{'Expected':<{left_width}} | {'Observed':<{right_width}}",
+            'Observed (left) == Expected (right)',
             *(l + ' | ' + r for l, r in zip(left_view_lines, right_view_lines))
         ]
         return diff_view
